@@ -200,10 +200,13 @@ class Maildir(DeliverySkeleton, ForkingBase):
                         'refuse to deliver mail as GID 0'
                     )
 
-        child = self.forkchild(
-            lambda o,e: self.__deliver_message_maildir(
-                uid, gid, msg, delivered_to, received, o, e)
-            )
+        try:
+            child = self.forkchild(
+                lambda o,e: self.__deliver_message_maildir(
+                    uid, gid, msg, delivered_to, received, o, e)
+                )
+        except getmailOperationError as oe:
+            raise getmailDeliveryError( 'delivery %s child operation error: %s' % (self, oe) )
 
         self.log.debug('maildir delivery process %d exited %d\n'
                        % (child.childpid, child.exitcode))
@@ -355,10 +358,13 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
                     'refuse to deliver mail as GID 0'
                 )
 
-        child = self.forkchild(
-            lambda o,e: self.__deliver_message_mbox(
-                uid, gid, msg, delivered_to, received, o, e)
-            )
+        try:
+            child = self.forkchild(
+                lambda o,e: self.__deliver_message_mbox(
+                    uid, gid, msg, delivered_to, received, o, e)
+                )
+        except getmailOperationError as oe:
+            raise getmailDeliveryError( 'delivery %s child operation error: %s' % (self, oe) )
 
         self.log.debug('mboxrd delivery process %d exited %d\n'
                        % (child.childpid, child.exitcode))
@@ -462,7 +468,7 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
     def showconf(self):
         self.log.info('MDA_qmaillocal(%s)\n' % self._confstring())
 
-    def _deliver_qmaillocal(self, msg, msginfo, delivered_to, received, stdout,
+    def __deliver_qmaillocal(self, msg, msginfo, delivered_to, received, stdout,
             stderr):
         try:
             args = (
@@ -522,10 +528,13 @@ class MDA_qmaillocal(DeliverySkeleton, ForkingBase):
         self.log.debug('recipient: set dash to "%s", ext to "%s"\n'
                        % (msginfo['dash'], msginfo['ext']))
 
-        child = self.forkchild(
-            lambda o,e: self._deliver_qmaillocal(
-                msg, msginfo, delivered_to, received, o, e)
-            )
+        try:
+            child = self.forkchild(
+                lambda o,e: self.__deliver_qmaillocal(
+                    msg, msginfo, delivered_to, received, o, e)
+                )
+        except getmailOperationError as oe:
+            raise getmailDeliveryError( 'delivery %s child operation error: %s' % (self, oe) )
 
 
         self.log.debug('qmail-local %d exited %d\n' % (child.childpid, child.exitcode))
@@ -592,9 +601,9 @@ class MDA_external(DeliverySkeleton, ForkingBase):
 
       ignore_stderr (boolean, optional) - if set, getmail will not consider the
             program writing to stderr to be an error.  The default is False.
-            
+
       pipe_stdout (boolean, optional) - if set, stdout from external command
-            will be forwarded to stdout of getmail.  The default is True. 
+            will be forwarded to stdout of getmail.  The default is True.
     '''
     _confitems = (
         ConfInstance(name='configparser', required=False),
@@ -614,7 +623,7 @@ class MDA_external(DeliverySkeleton, ForkingBase):
         if not os.access(self.conf['path'], os.X_OK):
             raise getmailConfigurationError('%s not executable'
                                             % self.conf['path'])
-        if type(self.conf['arguments']) != tuple:
+        if not isinstance(self.conf['arguments'], tuple):
             raise getmailConfigurationError(
                 'incorrect arguments format; see documentation (%s)'
                 % self.conf['arguments']
@@ -628,7 +637,7 @@ class MDA_external(DeliverySkeleton, ForkingBase):
     def showconf(self):
         self.log.info('MDA_external(%s)\n' % self._confstring())
 
-    def _deliver_command(self, msg, msginfo, delivered_to, received,
+    def __deliver_command(self, msg, msginfo, delivered_to, received,
                          stdout, stderr):
         try:
             args = [self.conf['path'], self.conf['path']]
@@ -654,14 +663,17 @@ class MDA_external(DeliverySkeleton, ForkingBase):
         self.log.trace()
         msginfo = self.get_msginfo(msg)
 
-        child = self.forkchild(
-            lambda o,e: self._deliver_command(
-                msg, msginfo, delivered_to, received, o, e)
-            )
-        
+        try:
+            child = self.forkchild(
+                lambda o,e: self.__deliver_command(
+                    msg, msginfo, delivered_to, received, o, e)
+                )
+        except getmailOperationError as oe:
+            raise getmailDeliveryError( 'delivery %s child operation error: %s' % (self, oe) )
+
         if self.conf['pipe_stdout'] and child.out:
             self.log.info('%s\n' % (''.join(map(chr, child.out))))
-        
+
         self.log.debug('command %s %d exited %d\n'
                        % (self.conf['command'], child.childpid, child.exitcode))
         if child.exitcode:
@@ -900,12 +912,12 @@ class MultiSorterBase(MultiDestinationBase):
         try:
             _locals = self.conf['locals']
             # Special case for convenience if user supplied one base 2-tuple
-            if (len(_locals) == 2 and type(_locals[0]) == str
-                    and type(_locals[1]) == str):
+            if (len(_locals) == 2 and
+                isinstance(_locals[0], str) and isinstance(_locals[1], str)):
                 _locals = (_locals, )
             for item in _locals:
-                if not (type(item) == tuple and len(item) == 2
-                        and type(item[0]) == str and type(item[1]) == str):
+                if (not isinstance(item, tuple) and len(item) == 2 and
+                    isinstance(item[0], str) and isinstance(item[1], str)):
                     raise getmailConfigurationError(
                         'invalid syntax for locals; see documentation'
                     )
@@ -963,7 +975,7 @@ class MultiSorter(MultiSorterBase):
                ("jason@example.org", "/home/jasonk/Maildir/"),
                ("sales@example.org", "/home/karlyk/Mail/sales"),
                ("abuse@(example.org|example.net)", "/home/kellyw/Mail/abuse/"),
-               ("^(jeff|jefferey)(\.s(mith)?)?@.*$", "[jeff-mail-delivery]"),
+               ("^(jeff|jefferey)(\\.s(mith)?)?@.*$", "[jeff-mail-delivery]"),
                ("^.*@(mail.)?rapinder.example.org$", "/home/rapinder/Maildir/")
                )
 
