@@ -1,24 +1,25 @@
+# -*- coding: utf-8 -*-
 # docs/COPYING 2a + DRY: https://github.com/getmail6/getmail6
 # Please refer to the git history regarding who changed what and when in this file.
 
 '''Logging support for getmail.
 
-The new standard Python libary module logging didn't cut it for me; it doesn't
+The new standard Python library module logging didn't cut it for me; it doesn't
 seem capable of handling some very simple requirements like logging messages of
 a certain level to one fd, and other messages of higher levels to a different fd
 (i.e. info to stdout, warnings to stderr).
 '''
 
-__all__ = [
-    'Logger',
-]
-
 import sys
 import os.path
 import traceback
 
 from getmailcore.constants import *
 
+__all__ = [
+    'Logger',
+]
+
 #######################################
 class _Logger(object):
     '''Class for logging.  Do not instantiate directly; use Logger() instead,
@@ -61,7 +62,15 @@ class _Logger(object):
                 continue
             if not handler['newline'] and msglevel == DEBUG:
                 handler['stream'].write('\n')
-            handler['stream'].write(msgtxt)
+            try:
+                handler['stream'].write(msgtxt)
+            except UnicodeError:
+                try:
+                    handler['stream'].write(
+                        msgtxt.encode('ascii',errors='backslashreplace').decode('ascii')
+                    )
+                except AttributeError:
+                    handler['stream'].write(msgtxt.decode('ascii',errors='backslashreplace'))
             handler['stream'].flush()
             if msgtxt.endswith('\n'):
                 handler['newline'] = True
