@@ -61,9 +61,8 @@ if sys.version_info.major > 2:
     unicode = str
     tostr = lambda lts: lts.decode()
 else:
-    unicode = unicode
     tostr = lambda lts: lts
-
+    unicode = unicode  # due to above unicode entry in __all__
 try:
     import ssl
 except ImportError:
